@@ -1,7 +1,8 @@
-use flow_impl::{Implementation, RUN_AGAIN, RunAgain};
-use flow_impl_derive::FlowImpl;
 use serde_json::Value;
 
+use flow_impl_derive::FlowImpl;
+use flowcore::{Implementation, RUN_AGAIN, RunAgain};
+
 #[derive(FlowImpl)]
 /// Select which data to output, based on a boolean control value.
 #[derive(Debug)]
@@ -24,4 +25,4 @@ impl Implementation for Select {
 
         (Some(Value::Object(output_map)), RUN_AGAIN)
     }
-}
\ No newline at end of file
+}
