@@ -1,7 +1,8 @@
-use flow_impl::{Implementation, RUN_AGAIN, RunAgain};
-use flow_impl_derive::FlowImpl;
 use serde_json::Value;
 
+use flow_impl_derive::FlowImpl;
+use flowcore::{Implementation, RUN_AGAIN, RunAgain};
+
 #[derive(FlowImpl)]
 /// Takes a value on it's input and sends the same value on it's output when it can
 /// run, effectively buffering it until the downstream processs can accept it.
@@ -16,10 +17,11 @@ impl Implementation for Buffer {
 
 #[cfg(test)]
 mod test {
-    use flow_impl::Implementation;
     use serde_json::json;
     use serde_json::Value;
 
+    use flowcore::Implementation;
+
     use super::Buffer;
 
     #[test]
@@ -37,6 +39,9 @@ mod test {
 
         let buffer = Buffer {};
         let runs_again = buffer.run(&[value]).1;
-        assert_eq!(runs_again, true, "Buffer should always be available to run again");
+        assert_eq!(
+            runs_again, true,
+            "Buffer should always be available to run again"
+        );
     }
-}
\ No newline at end of file
+}
